@@ -2,6 +2,8 @@ try:
     import tktooltip
 except ImportError:
     pass
+from typing import Literal
+import platform
 import tkinter as tk
 import tkinter.ttk as ttk
 import tkinter.tix as tix
@@ -9,11 +11,22 @@ from tkdev.devresize import DevResize
 from tkdev.devicon import Icon_Empty
 from ctypes import windll
 from os import environ
+from winrt import *
 
 try:
     from win32gui import *
     from win32con import *
     from win32api import *
+    from win32ui import *
+    from win32com import *
+except ImportError:
+    pass
+try:
+    import win32mica as mc
+except ImportError:
+    pass
+try:
+    import darkdetect
 except ImportError:
     pass
 
@@ -23,6 +36,45 @@ ScaleFactor = windll.shcore.GetScaleFactorForDevice(0)
 taskbar_height = GetMonitorInfo(MonitorFromPoint((0, 0))).get("Monitor")[3] - \
                  GetMonitorInfo(MonitorFromPoint((0, 0))).get("Work")[3]
 
+Auto = "auto"
+Light = "light"
+Dark = "dark"
+
+
+def window_long(window: tk.Tk, long):
+    def long():
+        hwnd = GetParent(window.winfo_id())
+        res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~long)
+    self.after(1, long)
+
+
+def window_ex_long(window: tk.Tk, long):
+    hwnd = GetParent(window.winfo_id())
+    res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~long)
+
+
+def window_tiled(window: tk.Tk):
+    hwnd = GetParent(window.winfo_id())
+    res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_TILED)
+
+
+def widget_max(widget: tk.Widget):
+    hwnd = GetParent(widget.winfo_id())
+    res = DefWindowProc(hwnd, HTHELP, None, None)
+
+
+def window_alpha(window: tk.Tk, alpha: int):
+    hwnd = GetParent(window.winfo_id())
+    res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_SIZEBOX)
+
+
+def window_mica_light(window: tk.Tk):
+    mc.ApplyMica(GetParent(window.winfo_id()), mc.MICAMODE.LIGHT)
+
+
+def window_mica_dark(window: tk.Tk):
+    mc.ApplyMica(GetParent(window.winfo_id()), mc.MICAMODE.DARK)
+
 
 def window_pos_bottom_right(window: tk.Tk, padx: int = 15, pady: int = 15):
     window.after(1, lambda: window.geometry(
@@ -124,6 +176,7 @@ def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
         toplevel.deiconify()
         if iswindow:
             window.attributes("-topmost", False)
+
     if iswindow:
         window.attributes("-topmost", True)
     window.after(1, embed)
@@ -610,19 +663,22 @@ class DevTitleBar(tk.Frame):
 
     def add_close(self, close_bg="#ffffff", close_fg="#000000", close_active_bg="#e81123", close_active_fg="#f5f5f5",
                   close_func=None):
-        self.closebutton = tk.Button(self, text='×', borderwidth=0, background=close_bg, foreground=close_fg, font=("微软雅黑", 13),
+        self.closebutton = tk.Button(self, text='×', borderwidth=0, background=close_bg, foreground=close_fg,
+                                     font=("微软雅黑", 13),
                                      activebackground=close_active_bg, command=close_func,
                                      activeforeground=close_active_fg)
         self.closebutton.pack(fill=tk.Y, side=self.button_side, ipadx=5)
 
     def add_max(self, max_bg="#ffffff", max_fg="#000000", max_active_bg="#c2c2c2", max_active_fg="#ffffff"):
-        self.maxbutton = tk.Button(self, text="▢", borderwidth=0, background=max_bg, foreground=max_fg, font=("微软雅黑", 13),
+        self.maxbutton = tk.Button(self, text="▢", borderwidth=0, background=max_bg, foreground=max_fg,
+                                   font=("微软雅黑", 13),
                                    activebackground=max_active_bg,
                                    activeforeground=max_active_fg)
         self.maxbutton.pack(fill=tk.Y, side=self.button_side, ipadx=5)
 
     def add_min(self, min_bg="#ffffff", min_fg="#000000", min_active_bg="#c2c2c2", min_active_fg="#ffffff"):
-        self.minbutton = tk.Button(self, text="-", borderwidth=0, background=min_bg, foreground=min_fg, font=("微软雅黑", 13),
+        self.minbutton = tk.Button(self, text="-", borderwidth=0, background=min_bg, foreground=min_fg,
+                                   font=("微软雅黑", 13),
                                    activebackground=min_active_bg,
                                    activeforeground=min_active_fg)
         self.minbutton.pack(fill=tk.Y, side=self.button_side, ipadx=8)
@@ -700,9 +756,31 @@ class DevWindow(tk.Tk):
         super(DevWindow, self).__init__()
         self.title(title)
         self.geometry("630x300")
-        self.configure(background="#ffffff")
         self.iconbitmap(Icon_Empty)
 
+    def wm_mica(self, mode: str = Literal["auto", "light", "dark"], all: bool = False):
+        if platform.system() == "Windows":
+            if all:
+                self.configure(background=self.cget("background"))
+                self.attributes("-transparent", self.cget("background"))
+                self.update()
+            if mode == "auto":
+                if darkdetect.isLight():
+                    window_mica_light(self)
+                    self.configure(background="#d3d3d3")
+                if darkdetect.isDark():
+                    window_mica_dark(self)
+                    self.configure(background="#000000")
+            elif mode == "light":
+                window_mica_light(self)
+                self.configure(background="#d3d3d3")
+            elif mode == "dark":
+                window_mica_dark(self)
+                self.configure(background="#000000")
+        self.update()
+
+    mica = wm_mica
+
     def wm_remove_titlebar(self):
         self.after(0, lambda: window_custom_border_taskbar(self))
 
@@ -752,7 +830,7 @@ class DevWindow(tk.Tk):
         self.state("iconic")
 
     def dpi(self):
-        self.tk.call('tk', 'scaling', ScaleFactor/75)
+        self.tk.call('tk', 'scaling', ScaleFactor / 75)
 
 
 class DevToplevel(tk.Toplevel, DevWindow):
@@ -760,12 +838,14 @@ class DevToplevel(tk.Toplevel, DevWindow):
         super(DevToplevel, self).__init__(master=master)
         self.title(title)
         self.geometry("630x300")
-        self.configure(background="#ffffff")
         self.iconbitmap(Icon_Empty)
 
 
 if __name__ == '__main__':
+    import sv_ttk
     Root = DevWindow()
-    TitleBar = DevTitleBar(Root, iswindow=True, window=Root)
-    Root.titlebar(TitleBar, overtitlebar=False)
+    Root.mica(Dark)
+    sv_ttk.use_dark_theme()
+    Button = ttk.Button(Root, text="Click Me")
+    Button.pack(fill=tk.BOTH, expand=tk.YES, pady=20, padx=20)
     Root.run()
